==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/C__241.h <==
// final class org.dellroad.jc.cgen.C$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8d3a2131e9ae182a org_dellroad_jc_cgen_C__241
// @dep_class ea216266fea08e5e org_dellroad_jc_cgen_Util__24PrimTypeSwitch
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch

// header file dependencies
// @dep_header org_dellroad_jc_cgen_Util__24PrimTypeSwitch

#include "org/dellroad/jc/cgen/Util__24PrimTypeSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_C__241_H_
#define _JC_org_dellroad_jc_cgen_C__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_C__241$sub_refs	_jc_org_dellroad_jc_cgen_C__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_C__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$refs	_jc_org_dellroad_jc_cgen_C__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$nonrefs	_jc_org_dellroad_jc_cgen_C__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$object	_jc_org_dellroad_jc_cgen_C__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_C__241$vmethods	_jc_org_dellroad_jc_cgen_C__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_C__241$vtable	_jc_org_dellroad_jc_cgen_C__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_C__241$vtype	_jc_org_dellroad_jc_cgen_C__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_C__241$method$_init$aa54f0755ac8f3ce(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_StringBuffer$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_C__241$method$prim$79dfdcd2a6a32c49(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_C__241$method_info$prim$79dfdcd2a6a32c49;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_C__241$vmethods {
	void	(*prim$79dfdcd2a6a32c49)(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_C__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$vmethods	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
	_jc_org_dellroad_jc_cgen_C__241$vmethods	org_dellroad_jc_cgen_C__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_C__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_C__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_C__241$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*val__24b;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_C__241$refs {
    _jc_org_dellroad_jc_cgen_C__241$sub_refs	org_dellroad_jc_cgen_C__241;
    _jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$sub_refs	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_C__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$sub_nonrefs	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
    _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs	org_dellroad_jc_cgen_C__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_C__241$object {
	_jc_org_dellroad_jc_cgen_C__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_C__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_C__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_C__241$vtype _jc_org_dellroad_jc_cgen_C__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_C__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_C__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_C__241_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/C__241.h <==
// final class org.dellroad.jc.cgen.C$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8d3a2131e9ae182a org_dellroad_jc_cgen_C__241
// @dep_class ea216266fea08e5e org_dellroad_jc_cgen_Util__24PrimTypeSwitch
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch

// header file dependencies
// @dep_header org_dellroad_jc_cgen_Util__24PrimTypeSwitch

#include "org/dellroad/jc/cgen/Util__24PrimTypeSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_C__241_H_
#define _JC_org_dellroad_jc_cgen_C__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_C__241$sub_refs	_jc_org_dellroad_jc_cgen_C__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_C__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$refs	_jc_org_dellroad_jc_cgen_C__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$nonrefs	_jc_org_dellroad_jc_cgen_C__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_C__241$object	_jc_org_dellroad_jc_cgen_C__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_C__241$vmethods	_jc_org_dellroad_jc_cgen_C__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_C__241$vtable	_jc_org_dellroad_jc_cgen_C__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_C__241$vtype	_jc_org_dellroad_jc_cgen_C__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_C__241$method$_init$aa54f0755ac8f3ce(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_C__241$method$prim$79dfdcd2a6a32c49(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_C__241$method_info$prim$79dfdcd2a6a32c49;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_C__241$vmethods {
	void	(*prim$79dfdcd2a6a32c49)(_jc_env *, struct _jc_org_dellroad_jc_cgen_C__241$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_C__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$vmethods	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
	_jc_org_dellroad_jc_cgen_C__241$vmethods	org_dellroad_jc_cgen_C__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_C__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_C__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_C__241$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*val__24b;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_C__241$refs {
    _jc_org_dellroad_jc_cgen_C__241$sub_refs	org_dellroad_jc_cgen_C__241;
    _jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$sub_refs	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_C__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__24PrimTypeSwitch$sub_nonrefs	org_dellroad_jc_cgen_Util__24PrimTypeSwitch;
    _jc_org_dellroad_jc_cgen_C__241$sub_nonrefs	org_dellroad_jc_cgen_C__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_C__241$object {
	_jc_org_dellroad_jc_cgen_C__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_C__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_C__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_C__241$vtype _jc_org_dellroad_jc_cgen_C__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_C__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_C__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_C__241_H_ */
